#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
import sys
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

DEFAULTDIR = '%stmp' % (path.sep)
SNAP_CMD = "/usr/sbin/snap"
SNAP_OUTPUT_DIR = path.sep + path.join("tmp", "ibmsupt.xiv")

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_directories()
        self.add_files()
        self.add_commands()
        self.add_snap()

    def add_directories(self):
        pass

    def add_files(self):
        self.add_collectable_item(DirectoryItem('xiv_devlist logs', self.archive, path.join(path.sep, 'var', 'log'), False, '.*xiv_devlist.*log.*'))

    def add_commands(self):
        pass

    def add_snap(self):
        if path.exists(SNAP_OUTPUT_DIR):
            print 'ERROR: snap dir "%s" already exists, please remove it first. ' % (SNAP_OUTPUT_DIR)
            sys.exit(1)

        cmdline = [ SNAP_CMD, "-GgkfLDd", SNAP_OUTPUT_DIR ]

        # Run snap and grab the output
        self.add_collectable_item(CommandItem('snap: output', cmdline,
                                              timeout=1000))
        # Now we need to pack the actual files
        self.add_collectable_item(DirectoryItem(\
                                     '%s directory' % (SNAP_OUTPUT_DIR),
                                     self.archive, SNAP_OUTPUT_DIR))
